@@ -217,7 +217,7 @@ void KNSBackend::receivedEntries(const KNSCore::EntryInternal::List& entries)
         Q_EMIT receivedResources(resources);
     }
 
-    if(resources.isEmpty() || m_stopSearching) {
+    if(resources.isEmpty()) {
         Q_EMIT searchFinished();
         Q_EMIT availableForQueries();
         setFetching(false);
@@ -253,6 +253,14 @@ public:
         auto manager = res->knsBackend()->engine();
         connect(manager, &KNSCore::Engine::signalEntryChanged, this, &KNSTransaction::anEntryChanged);
         TransactionModel::global()->addTransaction(this);
+
+        QTimer::singleShot(0, this, [this, res]() {
+            auto engine = res->knsBackend()->engine();
+            if (this->role() == InstallRole)
+                engine->install(res->entry());
+            else if(this->role() == RemoveRole)
+                engine->uninstall(res->entry());
+        });
     }
 
     void anEntryChanged(const KNSCore::EntryInternal& entry) {
@@ -286,15 +294,12 @@ private:
 Transaction* KNSBackend::removeApplication(AbstractResource* app)
 {
     auto res = qobject_cast<KNSResource*>(app);
-    auto t = new KNSTransaction(this, res, Transaction::RemoveRole);
-    m_engine->uninstall(res->entry());
-    return t;
+    return new KNSTransaction(this, res, Transaction::RemoveRole);
 }
 
 Transaction* KNSBackend::installApplication(AbstractResource* app)
 {
     auto res = qobject_cast<KNSResource*>(app);
-    m_engine->install(res->entry());
     return new KNSTransaction(this, res, Transaction::InstallRole);
 }
 
@@ -351,12 +356,6 @@ ResultsStream* KNSBackend::searchStream(const QString &searchText)
         m_onePage = false;
         m_responsePending = true;
 
-        QSharedPointer<int> count(new int(0));
-        connect(this, &KNSBackend::receivedResources, stream, [this, count](const QVector<AbstractResource*>& resources){
-            *count += resources.count();
-            if (*count>2000)
-                m_stopSearching = true;
-        });
         connect(this, &KNSBackend::receivedResources, stream, &ResultsStream::resourcesFound);
         connect(this, &KNSBackend::searchFinished, stream, &ResultsStream::finish);
         connect(this, &KNSBackend::startingSearch, stream, &ResultsStream::finish);
@@ -392,7 +391,8 @@ ResultsStream * KNSBackend::findResourceByPackageName(const QUrl& search)
         connect(m_engine, &KNSCore::Engine::signalEntryDetailsLoaded, stream, [this, stream, entryid, providerid](const KNSCore::EntryInternal &entry) {
             if (entry.uniqueId() == entryid && providerid == QUrl(entry.providerId()).host()) {
                 stream->resourcesFound({resourceForEntry(entry)});
-            }
+            } else
+                qWarning() << "found invalid" << entryid << entry.uniqueId() << providerid << QUrl(entry.providerId()).host();
             m_responsePending = false;
             QTimer::singleShot(0, this, &KNSBackend::availableForQueries);
             stream->finish();
