@@ -26,21 +26,20 @@
 #include <QProcess>
 #include <QJsonDocument>
 #include <QJsonArray>
+#include <KLocalizedString>
 #include "libsnapclient/config-paths.h"
 #include "utils.h"
 
-SnapTransaction::SnapTransaction(SnapResource* app, QSnapdRequest* request, Role role)
+SnapTransaction::SnapTransaction(QSnapdClient* client, SnapResource* app, Role role, AbstractResource::State newState)
     : Transaction(app, app, role)
+    , m_client(client)
     , m_app(app)
-    , m_request(request)
+    , m_newState(newState)
 {
-    setStatus(DownloadingStatus);
-    setCancellable(false);
-    connect(request, &QSnapdRequest::progress, this, &SnapTransaction::progressed);
-    connect(request, &QSnapdRequest::complete, this, &SnapTransaction::finishTransaction);
-    setStatus(SetupStatus);
-
-    request->runAsync();
+    if (role == RemoveRole)
+        setRequest(m_client->remove(app->packageName()));
+    else
+        setRequest(m_client->install(app->packageName()));
 }
 
 void SnapTransaction::cancel()
@@ -50,10 +49,16 @@ void SnapTransaction::cancel()
 
 void SnapTransaction::finishTransaction()
 {
-    qDebug() << "done!";
     switch(m_request->error()) {
         case QSnapdRequest::NoError:
             static_cast<SnapBackend*>(m_app->backend())->refreshStates();
+            m_app->setState(m_newState);
+            break;
+        case QSnapdRequest::NeedsClassic:
+            if (role() == Transaction::InstallRole) {
+                Q_EMIT proceedRequest(m_app->name(), i18n("This snap application needs security confinement measures disabled."));
+                return;
+            }
             break;
         case QSnapdRequest::AuthDataRequired: {
             QProcess* p = new QProcess;
@@ -78,6 +83,7 @@ void SnapTransaction::finishTransaction()
             });
         }   return;
         default:
+            qDebug() << "snap error" << m_request << m_request->error() << m_request->errorString();
             Q_EMIT passiveMessage(m_request->errorString());
             break;
     }
@@ -85,6 +91,24 @@ void SnapTransaction::finishTransaction()
     setStatus(DoneStatus);
 }
 
+void SnapTransaction::proceed()
+{
+    setRequest(m_client->install(QSnapdClient::Classic, m_app->packageName()));
+}
+
+void SnapTransaction::setRequest(QSnapdRequest* req)
+{
+    m_request.reset(req);
+
+    setCancellable(false);
+    connect(m_request.data(), &QSnapdRequest::progress, this, &SnapTransaction::progressed);
+    connect(m_request.data(), &QSnapdRequest::complete, this, &SnapTransaction::finishTransaction);
+    setStatus(SetupStatus);
+
+    setStatus(DownloadingStatus);
+    m_request->runAsync();
+}
+
 void SnapTransaction::progressed()
 {
     const auto change = m_request->change();
